@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp qw(croak confess);
 
-use version; our $VERSION = qv('2.00.02');
+use version; our $VERSION = qv('2.00.03');
 
 use SOAP::WSDL::XSD::Typelib::Builtin;
 use SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType;
@@ -319,11 +319,11 @@ the same terms as perl itself
 
 =head1 Repository information
 
- $Id: MessageParser.pm 672 2008-05-16 09:37:59Z kutterma $
+ $Id: MessageParser.pm 677 2008-05-18 20:17:56Z kutterma $
 
- $LastChangedDate: 2008-05-16 11:37:59 +0200 (Fr, 16 Mai 2008) $
- $LastChangedRevision: 672 $
+ $LastChangedDate: 2008-05-18 22:17:56 +0200 (So, 18 Mai 2008) $
+ $LastChangedRevision: 677 $
  $LastChangedBy: kutterma $
 
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/MessageParser.pm $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/MessageParser.pm $
 
